@@ -548,16 +548,6 @@ class emailmgmt {
                 return ['status' => '1', 'msg' => 'Invalid destination email address format'];
             }
             
-            // Check if forwarder already exists
-            $stmt = $this->db->prepare("
-                SELECT id FROM whp.email_forwarders 
-                WHERE source_email = ? AND destination_email = ?
-            ");
-            $stmt->execute([$source_email, $destination_email]);
-            if ($stmt->fetch()) {
-                return ['status' => '1', 'msg' => 'Email forwarder already exists'];
-            }
-            
             // Verify that the source email domain belongs to the user
             $domain = explode('@', $source_email)[1];
             $stmt = $this->db->prepare("
@@ -569,25 +559,52 @@ class emailmgmt {
                 return ['status' => '1', 'msg' => 'Source email domain not found or not owned by user'];
             }
             
-            // Create forwarder on mail server if client is available
+            // Check if this specific destination already exists
+            $stmt = $this->db->prepare("
+                SELECT id FROM whp.email_forwarders 
+                WHERE source_email = ? AND destination_email = ?
+            ");
+            $stmt->execute([$source_email, $destination_email]);
+            if ($stmt->fetch()) {
+                return ['status' => '1', 'msg' => 'This forwarder destination already exists'];
+            }
+            
+            // Get all existing destinations for this source email (including the new one we're about to add)
+            $stmt = $this->db->prepare("
+                SELECT destination_email FROM whp.email_forwarders 
+                WHERE source_email = ? AND active = 1
+            ");
+            $stmt->execute([$source_email]);
+            $existing_destinations = $stmt->fetchAll(PDO::FETCH_COLUMN);
+            
+            // Add the new destination to the array
+            $all_destinations = $existing_destinations;
+            $all_destinations[] = $destination_email;
+            
+            // Update forwarder on mail server with all destinations
             if ($this->mail_client) {
                 try {
                     $username_part = explode('@', $source_email)[0];
-                    $this->mail_client->createEmailForwarder($source_email, $destination_email, $username_part);
+                    // Pass all destinations as an array to the mail server
+                    $this->mail_client->createEmailForwarder($source_email, $all_destinations, $username_part);
                 } catch (Exception $e) {
-                    error_log("Failed to create email forwarder on mail server: " . $e->getMessage());
-                    return ['status' => '1', 'msg' => 'Failed to create email forwarder on mail server: ' . $e->getMessage()];
+                    error_log("Failed to update email forwarder on mail server: " . $e->getMessage());
+                    return ['status' => '1', 'msg' => 'Failed to update email forwarder on mail server: ' . $e->getMessage()];
                 }
             }
             
-            // Create forwarder in database
+            // Add new destination to database
             $stmt = $this->db->prepare("
                 INSERT INTO whp.email_forwarders (source_email, destination_email, username)
                 VALUES (?, ?, ?)
             ");
             $stmt->execute([$source_email, $destination_email, $username]);
             
-            return ['status' => '0', 'msg' => 'Email forwarder created successfully'];
+            $msg = empty($existing_destinations) ? 
+                   'Email forwarder created successfully' : 
+                   'Email forwarder destination added successfully';
+            
+            return ['status' => '0', 'msg' => $msg];
             
         } catch (Exception $e) {
             error_log("Failed to create email forwarder: " . $e->getMessage());
@@ -606,7 +623,7 @@ class emailmgmt {
         try {
             // Check if forwarder exists and user has permission
             $stmt = $this->db->prepare("
-                SELECT id, username, source_email FROM whp.email_forwarders WHERE id = ?
+                SELECT id, username, source_email, destination_email FROM whp.email_forwarders WHERE id = ?
             ");
             $stmt->execute([$forwarder_id]);
             $forwarder = $stmt->fetch(PDO::FETCH_ASSOC);
@@ -620,23 +637,42 @@ class emailmgmt {
                 return ['status' => '1', 'msg' => 'Permission denied'];
             }
             
-            // Delete from mail server if client is available
-            if ($this->mail_client && $forwarder['source_email']) {
-                try {
-                    $this->mail_client->deleteEmailForwarder($forwarder['source_email']);
-                } catch (Exception $e) {
-                    error_log("Failed to delete email forwarder from mail server: " . $e->getMessage());
-                    // Continue with database deletion even if mail server fails
-                }
-            }
-            
-            // Hard delete from database
+            // Delete this specific destination from database
             $stmt = $this->db->prepare("
                 DELETE FROM whp.email_forwarders WHERE id = ?
             ");
             $stmt->execute([$forwarder_id]);
             
-            return ['status' => '0', 'msg' => 'Email forwarder deleted successfully'];
+            // Check if there are other destinations remaining for this source email
+            $stmt = $this->db->prepare("
+                SELECT destination_email FROM whp.email_forwarders 
+                WHERE source_email = ? AND active = 1
+            ");
+            $stmt->execute([$forwarder['source_email']]);
+            $remaining_destinations = $stmt->fetchAll(PDO::FETCH_COLUMN);
+            
+            // Update mail server
+            if ($this->mail_client && $forwarder['source_email']) {
+                try {
+                    if (empty($remaining_destinations)) {
+                        // No more destinations, delete the forwarder entirely
+                        $this->mail_client->deleteEmailForwarder($forwarder['source_email']);
+                    } else {
+                        // Update the forwarder with remaining destinations
+                        $username_part = explode('@', $forwarder['source_email'])[0];
+                        $this->mail_client->createEmailForwarder($forwarder['source_email'], $remaining_destinations, $username_part);
+                    }
+                } catch (Exception $e) {
+                    error_log("Failed to update email forwarder on mail server: " . $e->getMessage());
+                    // Continue even if mail server update fails
+                }
+            }
+            
+            $msg = empty($remaining_destinations) ? 
+                   'Email forwarder deleted successfully' : 
+                   'Email forwarder destination removed successfully';
+            
+            return ['status' => '0', 'msg' => $msg];
             
         } catch (Exception $e) {
             error_log("Failed to delete email forwarder: " . $e->getMessage());
